mercurial/commands.py
changeset 19409 ea4342d0e6fe
parent 19403 9013f2930a4a
child 19421 b2b08be5f556
--- a/mercurial/commands.py	Tue Jul 16 15:18:12 2013 -0500
+++ b/mercurial/commands.py	Tue Jul 16 17:10:26 2013 -0500
@@ -3541,7 +3541,8 @@
        'meaning as the corresponding patch option'), _('NUM')),
     ('b', 'base', '', _('base path (DEPRECATED)'), _('PATH')),
     ('e', 'edit', False, _('invoke editor on commit messages')),
-    ('f', 'force', None, _('skip check for outstanding uncommitted changes')),
+    ('f', 'force', None,
+     _('skip check for outstanding uncommitted changes (DEPRECATED)')),
     ('', 'no-commit', None,
      _("don't commit, just update the working directory")),
     ('', 'bypass', None,
@@ -3558,8 +3559,8 @@
     Import a list of patches and commit them individually (unless
     --no-commit is specified).
 
-    If there are outstanding changes in the working directory, import
-    will abort unless given the -f/--force flag.
+    Because import first applies changes to the working directory,
+    import will abort if there are outstanding changes.
 
     You can import a patch straight from a mail message. Even patches
     as attachments work (to use the body part, it must have type
@@ -5013,7 +5014,7 @@
 @command('rollback', dryrunopts +
          [('f', 'force', False, _('ignore safety measures'))])
 def rollback(ui, repo, **opts):
     """roll back the last transaction (dangerous)
 
     This command should be used with care. There is only one level of
     rollback, and there is no way to undo a rollback. It will also
@@ -5013,7 +5014,7 @@
          [('f', 'force', False, _('ignore safety measures'))])
 def rollback(ui, repo, **opts):
-    """roll back the last transaction (dangerous)
+    """roll back the last transaction (DANGEROUS) (DEPRECATED)
 
     This command should be used with care. There is only one level of